@@ -1,9 +1,11 @@
 from typing import Optional
 
-from .molecule import Molecule
 from .base import Base, LowercaseStrEnum
+from .message import Message
+from .molecule import Molecule
 from .settings import Settings
 from .status import Status
+from .types import UUID
 
 
 class StJamesVersion(LowercaseStrEnum):
@@ -25,8 +27,10 @@ class Calculation(Base):
     name: Optional[str] = None
     elapsed: Optional[float] = None
     logfile: Optional[str] = None
+    messages: list[Message] = []
 
-    engine: Optional[str] = "kestrel"
+    engine: Optional[str] = "peregrine"
+    uuids: list[UUID | None] | None = None
 
     # not to be changed by end users, diff. versions will have diff. defaults
     json_format: str = StJamesVersion.V0
